@@ -1,16 +1,13 @@
-#ifndef lint
-static char rcsId[]="$Header: /debian/home/gnomecvs/gnome-libs/gtk-xmhtml/LZWStream.c,v 1.3 1998/02/12 03:07:53 unammx Exp $";
-#endif
 /*****
 * LZWStream.c : LZW uncompressor that doesn't use the LZW algorithm but
 *				converts LZW compressed data to compress LZW data and
 *				calls compress to do the uncompressing.
 *
-* This file Version	$Revision: 1.3 $
+* This file Version	$Revision: 1.4 $
 *
 * Creation date:		Thu May  8 04:53:42 GMT+0100 1997
-* Last modification: 	$Date: 1998/02/12 03:07:53 $
-* By:					$Author: unammx $
+* Last modification: 	$Date: 1999/07/29 01:26:28 $
+* By:					$Author: sopwith $
 * Current State:		$State: Exp $
 *
 * Author:				newt
@@ -34,6 +31,11 @@ static char rcsId[]="$Header: /debian/home/gnomecvs/gnome-libs/gtk-xmhtml/LZWStr
 /*****
 * ChangeLog 
 * $Log: LZWStream.c,v $
+* Revision 1.4  1999/07/29 01:26:28  sopwith
+*
+*
+* Fix all warnings.
+*
 * Revision 1.3  1998/02/12 03:07:53  unammx
 * Merge to Koen's XmHTML 1.1.2 + following fixes:
 *
