@@ -37,7 +37,7 @@
  * art_affine_point: Do an affine transformation of a point.
  * @dst: Where the result point is stored.
  * @src: The original point.
- @ @affine: The affine transformation.
+ * @affine: The affine transformation.
  **/
 void
 art_affine_point (ArtPoint *dst, const ArtPoint *src,
@@ -53,8 +53,8 @@ art_affine_point (ArtPoint *dst, const ArtPoint *src,
 
 /**
  * art_affine_invert: Find the inverse of an affine transformation.
- * @dst: Where the resulting affine is stored.
- * @src: The original affine transformation.
+ * @dst_affine: Where the resulting affine is stored.
+ * @src_affine: The original affine transformation.
  *
  * All non-degenerate affine transforms are invertible. If the original
  * affine is degenerate or nearly so, expect numerical instability and
@@ -80,7 +80,7 @@ art_affine_invert (double dst[6], const double src[6])
  * art_affine_flip: Flip an affine transformation horizontally and/or vertically.
  * @dst_affine: Where the resulting affine is stored.
  * @src_affine: The original affine transformation.
- * @horiz: Whether or not to flip horizontally.
+ * @horz: Whether or not to flip horizontally.
  * @vert: Whether or not to flip horizontally.
  *
  * Flips the affine transform. FALSE for both @horiz and @vert implements
@@ -214,7 +214,11 @@ art_affine_to_string (char str[128], const double src[6])
 	    }
 	  else
 	    {
-	      sprintf (str, "%g %g scale", src[0], src[3]);
+	      ix = 0;
+	      ix += art_ftoa (str + ix, src[0]);
+	      str[ix++] = ' ';
+	      ix += art_ftoa (str + ix, src[3]);
+	      strcpy (str + ix, " scale");
 	      return;
 	    }
 	}
@@ -240,7 +244,11 @@ art_affine_to_string (char str[128], const double src[6])
       if (fabs (src[0] - 1) < EPSILON && fabs (src[1]) < EPSILON &&
 	  fabs (src[2]) < EPSILON && fabs (src[3] - 1) < EPSILON)
 	{
-	  sprintf (str, "%g %g translate", src[4], src[5]);
+	  ix = 0;
+	  ix += art_ftoa (str + ix, src[4]);
+	  str[ix++] = ' ';
+	  ix += art_ftoa (str + ix, src[5]);
+	  strcpy (str + ix, " translate");
 	  return;
 	}
     }
@@ -378,7 +386,7 @@ art_affine_shear (double dst[6], double theta)
  * art_affine_translate: Set up a translation matrix.
  * @dst: Where to store the resulting affine transform.
  * @tx: X translation amount.
- * @tx: Y translation amount.
+ * @ty: Y translation amount.
  *
  * Sets up a translation matrix.
  **/
