@@ -140,7 +140,7 @@ struct _ZvtTermClass
 typedef enum {
   ZVT_FONT_1BYTE=0,		/* simple, 1-byte fonts */
   ZVT_FONT_2BYTE,		/* 2-byte fonts */
-  ZVT_FONT_FONTSET,		/* fontset fonts */
+  ZVT_FONT_FONTSET		/* fontset fonts */
 } zvtfont_t;
 
 /* private data structure, stored under "_zvtprivate" */
